pub struct PropertyCheckResult<'tcx> {
pub checkpoint: CheckpointLocation,
pub checkpoint_index: usize,
pub path_index: usize,
pub property_index: usize,
pub property: Property<'tcx>,
pub result: CheckResult,
pub diagnostics: Option<VisitDiagnostics>,
pub path_description: String,
pub callee_name: String,
}Expand description
Result for one required property along one path to a checkpoint.
Fields
checkpoint: CheckpointLocationUnsafe checkpoint being checked.
checkpoint_index: usizeIndex of the checkpoint in the function-level checkpoint list.
path_index: usizeIndex of the path in the checkpoint path set.
property_index: usizeIndex of the property in the checkpoint-level property list.
property: Property<'tcx>Required property checked on this path.
result: CheckResultCurrent verification status.
diagnostics: Option<VisitDiagnostics>Optional path-local diagnostics generated by the staged visitors.
path_description: StringHuman-readable path description.
callee_name: StringCallee name for this checkpoint.